"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Connector_1 = require("./Connector");
const fs = require("fs");
class ConnectorFactory {
    constructor(configuration, ldapjs, logger) {
        this.configuration = configuration;
        this.ldapjs = ldapjs;
        this.logger = logger;
    }
    create() {
        const options = {
            url: this.configuration.url,
            reconnect: this.configuration.reconnect
        };
        if (this.configuration.caCert && (this.configuration.url.toLowerCase().startsWith("ldaps"))) {
            this.logger.info("Reading CA certificate from: %s", this.configuration.caCert);
            options.tlsOptions = {
                ca: [fs.readFileSync(this.configuration.caCert, "utf-8")],
            };
        }
        this.logger.debug("Using ldap client options: %s", JSON.stringify(options));
        return new Connector_1.Connector(options, this.ldapjs);
    }
}
exports.ConnectorFactory = ConnectorFactory;
//# sourceMappingURL=ConnectorFactory.js.map